@@ -12,5 +12,5 @@ class Atom:
     terms: tuple[Constant | Variable, ...]
 
     def __str__(self) -> str:
-        terms_str = ",".join([term.__str__() for term in self.terms])
-        return f"{self.predicate}({terms_str})"
+        terms_str = ",".join([str(term) for term in self.terms])
+        return f"{self.predicate.symbol}({terms_str})"
